@import url("gx_head_Guitarix.css");gx-paint-box{-GxPaintBox-icon-set:19;-GxPaintBox-stock-gxhead:"live_wallpaper_sky.png"}frame,#frame_inversed,frame border,#frame_inversed border{background-color:transparent}frame border,#frame_inversed border{border-color:black}
